# genconf_script

This is a simple Python package created as a proof-of-concept and side project to demonstrate web scraping and simple package creation skills. The subject matter for this package was chosen primarily for its familiarity to the package's creator.

The package allows the user to interact with footnotes from talks given at the General Conference of the Church of Jesus Christ of Latter-day Saints, a semi-annual event at which the church's leaders speak. Using the package, the user can identify talks that reference a given verse from the Book of Mormon, one of the books of scripture utilized by members of the aforementioned church. 

